# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/tools/prediction/data_pipelines/proto/cruise_model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/tools/prediction/data_pipelines/proto/cruise_model.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@modules/tools/prediction/data_pipelines/proto/cruise_model.proto\"2\n\x0fTensorParameter\x12\x10\n\x04\x64\x61ta\x18\x01 \x03(\x02\x42\x02\x10\x01\x12\r\n\x05shape\x18\x02 \x03(\x05\"D\n\x0eInputParameter\x12\x13\n\x0binput_shape\x18\x01 \x03(\x05\x12\r\n\x05\x64type\x18\x02 \x01(\t\x12\x0e\n\x06sparse\x18\x03 \x01(\x08\"\x84\x01\n\x0f\x43onv1dParameter\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x10\n\x08use_bias\x18\x02 \x01(\x08\x12 \n\x06kernel\x18\x03 \x01(\x0b\x32\x10.TensorParameter\x12\x1e\n\x04\x62ias\x18\x04 \x01(\x0b\x32\x10.TensorParameter\x12\x0e\n\x06stride\x18\x05 \x01(\x05\"\x88\x01\n\x0e\x44\x65nseParameter\x12\r\n\x05units\x18\x01 \x01(\x05\x12\x12\n\nactivation\x18\x02 \x01(\t\x12\x10\n\x08use_bias\x18\x03 \x01(\x08\x12!\n\x07weights\x18\x04 \x01(\x0b\x32\x10.TensorParameter\x12\x1e\n\x04\x62ias\x18\x05 \x01(\x0b\x32\x10.TensorParameter\")\n\x13\x41\x63tivationParameter\x12\x12\n\nactivation\x18\x01 \x01(\t\"9\n\x12MaxPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"9\n\x12\x41vgPool1dParameter\x12\x13\n\x0bkernel_size\x18\x01 \x01(\x05\x12\x0e\n\x06stride\x18\x02 \x01(\x05\"\xde\x01\n\x18LaneFeatureConvParameter\x12\"\n\x08\x63onv1d_0\x18\x01 \x01(\x0b\x32\x10.Conv1dParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12\"\n\x08\x63onv1d_2\x18\x03 \x01(\x0b\x32\x10.Conv1dParameter\x12*\n\x0c\x61\x63tivation_3\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\x12\"\n\x08\x63onv1d_4\x18\x05 \x01(\x0b\x32\x10.Conv1dParameter\"\xb5\x01\n\x15ObsFeatureFCParameter\x12!\n\x08linear_0\x18\x01 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_3\x18\x03 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_4\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\"\xd0\x02\n\x11\x43lassifyParameter\x12!\n\x08linear_0\x18\x01 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_3\x18\x03 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_4\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_6\x18\x05 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_7\x18\x06 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_9\x18\x07 \x01(\x0b\x32\x0f.DenseParameter\x12+\n\ractivation_10\x18\x08 \x01(\x0b\x32\x14.ActivationParameter\"\xcf\x02\n\x10RegressParameter\x12!\n\x08linear_0\x18\x01 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_1\x18\x02 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_3\x18\x03 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_4\x18\x04 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_6\x18\x05 \x01(\x0b\x32\x0f.DenseParameter\x12*\n\x0c\x61\x63tivation_7\x18\x06 \x01(\x0b\x32\x14.ActivationParameter\x12!\n\x08linear_9\x18\x07 \x01(\x0b\x32\x0f.DenseParameter\x12+\n\ractivation_10\x18\x08 \x01(\x0b\x32\x14.ActivationParameter\"\xac\x02\n\x14\x43ruiseModelParameter\x12\x34\n\x11lane_feature_conv\x18\x01 \x01(\x0b\x32\x19.LaneFeatureConvParameter\x12\x31\n\x14lane_feature_maxpool\x18\x02 \x01(\x0b\x32\x13.MaxPool1dParameter\x12\x31\n\x14lane_feature_avgpool\x18\x03 \x01(\x0b\x32\x13.AvgPool1dParameter\x12.\n\x0eobs_feature_fc\x18\x05 \x01(\x0b\x32\x16.ObsFeatureFCParameter\x12$\n\x08\x63lassify\x18\x06 \x01(\x0b\x32\x12.ClassifyParameter\x12\"\n\x07regress\x18\x07 \x01(\x0b\x32\x11.RegressParameter'
)




_TENSORPARAMETER = _descriptor.Descriptor(
  name='TensorParameter',
  full_name='TensorParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='TensorParameter.data', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='TensorParameter.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=118,
)


_INPUTPARAMETER = _descriptor.Descriptor(
  name='InputParameter',
  full_name='InputParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_shape', full_name='InputParameter.input_shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtype', full_name='InputParameter.dtype', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sparse', full_name='InputParameter.sparse', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=188,
)


_CONV1DPARAMETER = _descriptor.Descriptor(
  name='Conv1dParameter',
  full_name='Conv1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='Conv1dParameter.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='Conv1dParameter.use_bias', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernel', full_name='Conv1dParameter.kernel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='Conv1dParameter.bias', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='Conv1dParameter.stride', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=323,
)


_DENSEPARAMETER = _descriptor.Descriptor(
  name='DenseParameter',
  full_name='DenseParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='DenseParameter.units', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation', full_name='DenseParameter.activation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_bias', full_name='DenseParameter.use_bias', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights', full_name='DenseParameter.weights', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bias', full_name='DenseParameter.bias', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=462,
)


_ACTIVATIONPARAMETER = _descriptor.Descriptor(
  name='ActivationParameter',
  full_name='ActivationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation', full_name='ActivationParameter.activation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=505,
)


_MAXPOOL1DPARAMETER = _descriptor.Descriptor(
  name='MaxPool1dParameter',
  full_name='MaxPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='MaxPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='MaxPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=564,
)


_AVGPOOL1DPARAMETER = _descriptor.Descriptor(
  name='AvgPool1dParameter',
  full_name='AvgPool1dParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_size', full_name='AvgPool1dParameter.kernel_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stride', full_name='AvgPool1dParameter.stride', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=623,
)


_LANEFEATURECONVPARAMETER = _descriptor.Descriptor(
  name='LaneFeatureConvParameter',
  full_name='LaneFeatureConvParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='conv1d_0', full_name='LaneFeatureConvParameter.conv1d_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='LaneFeatureConvParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conv1d_2', full_name='LaneFeatureConvParameter.conv1d_2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_3', full_name='LaneFeatureConvParameter.activation_3', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conv1d_4', full_name='LaneFeatureConvParameter.conv1d_4', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=848,
)


_OBSFEATUREFCPARAMETER = _descriptor.Descriptor(
  name='ObsFeatureFCParameter',
  full_name='ObsFeatureFCParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear_0', full_name='ObsFeatureFCParameter.linear_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='ObsFeatureFCParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_3', full_name='ObsFeatureFCParameter.linear_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_4', full_name='ObsFeatureFCParameter.activation_4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=1032,
)


_CLASSIFYPARAMETER = _descriptor.Descriptor(
  name='ClassifyParameter',
  full_name='ClassifyParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear_0', full_name='ClassifyParameter.linear_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='ClassifyParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_3', full_name='ClassifyParameter.linear_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_4', full_name='ClassifyParameter.activation_4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_6', full_name='ClassifyParameter.linear_6', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_7', full_name='ClassifyParameter.activation_7', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_9', full_name='ClassifyParameter.linear_9', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_10', full_name='ClassifyParameter.activation_10', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1371,
)


_REGRESSPARAMETER = _descriptor.Descriptor(
  name='RegressParameter',
  full_name='RegressParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear_0', full_name='RegressParameter.linear_0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_1', full_name='RegressParameter.activation_1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_3', full_name='RegressParameter.linear_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_4', full_name='RegressParameter.activation_4', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_6', full_name='RegressParameter.linear_6', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_7', full_name='RegressParameter.activation_7', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_9', full_name='RegressParameter.linear_9', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_10', full_name='RegressParameter.activation_10', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1709,
)


_CRUISEMODELPARAMETER = _descriptor.Descriptor(
  name='CruiseModelParameter',
  full_name='CruiseModelParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_feature_conv', full_name='CruiseModelParameter.lane_feature_conv', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_feature_maxpool', full_name='CruiseModelParameter.lane_feature_maxpool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_feature_avgpool', full_name='CruiseModelParameter.lane_feature_avgpool', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obs_feature_fc', full_name='CruiseModelParameter.obs_feature_fc', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classify', full_name='CruiseModelParameter.classify', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regress', full_name='CruiseModelParameter.regress', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1712,
  serialized_end=2012,
)

_CONV1DPARAMETER.fields_by_name['kernel'].message_type = _TENSORPARAMETER
_CONV1DPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_DENSEPARAMETER.fields_by_name['weights'].message_type = _TENSORPARAMETER
_DENSEPARAMETER.fields_by_name['bias'].message_type = _TENSORPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['conv1d_0'].message_type = _CONV1DPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['conv1d_2'].message_type = _CONV1DPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['activation_3'].message_type = _ACTIVATIONPARAMETER
_LANEFEATURECONVPARAMETER.fields_by_name['conv1d_4'].message_type = _CONV1DPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['linear_0'].message_type = _DENSEPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['linear_3'].message_type = _DENSEPARAMETER
_OBSFEATUREFCPARAMETER.fields_by_name['activation_4'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_0'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_3'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_4'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_6'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_7'].message_type = _ACTIVATIONPARAMETER
_CLASSIFYPARAMETER.fields_by_name['linear_9'].message_type = _DENSEPARAMETER
_CLASSIFYPARAMETER.fields_by_name['activation_10'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_0'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_1'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_3'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_4'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_6'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_7'].message_type = _ACTIVATIONPARAMETER
_REGRESSPARAMETER.fields_by_name['linear_9'].message_type = _DENSEPARAMETER
_REGRESSPARAMETER.fields_by_name['activation_10'].message_type = _ACTIVATIONPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['lane_feature_conv'].message_type = _LANEFEATURECONVPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['lane_feature_maxpool'].message_type = _MAXPOOL1DPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['lane_feature_avgpool'].message_type = _AVGPOOL1DPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['obs_feature_fc'].message_type = _OBSFEATUREFCPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['classify'].message_type = _CLASSIFYPARAMETER
_CRUISEMODELPARAMETER.fields_by_name['regress'].message_type = _REGRESSPARAMETER
DESCRIPTOR.message_types_by_name['TensorParameter'] = _TENSORPARAMETER
DESCRIPTOR.message_types_by_name['InputParameter'] = _INPUTPARAMETER
DESCRIPTOR.message_types_by_name['Conv1dParameter'] = _CONV1DPARAMETER
DESCRIPTOR.message_types_by_name['DenseParameter'] = _DENSEPARAMETER
DESCRIPTOR.message_types_by_name['ActivationParameter'] = _ACTIVATIONPARAMETER
DESCRIPTOR.message_types_by_name['MaxPool1dParameter'] = _MAXPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['AvgPool1dParameter'] = _AVGPOOL1DPARAMETER
DESCRIPTOR.message_types_by_name['LaneFeatureConvParameter'] = _LANEFEATURECONVPARAMETER
DESCRIPTOR.message_types_by_name['ObsFeatureFCParameter'] = _OBSFEATUREFCPARAMETER
DESCRIPTOR.message_types_by_name['ClassifyParameter'] = _CLASSIFYPARAMETER
DESCRIPTOR.message_types_by_name['RegressParameter'] = _REGRESSPARAMETER
DESCRIPTOR.message_types_by_name['CruiseModelParameter'] = _CRUISEMODELPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TensorParameter = _reflection.GeneratedProtocolMessageType('TensorParameter', (_message.Message,), {
  'DESCRIPTOR' : _TENSORPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:TensorParameter)
  })
_sym_db.RegisterMessage(TensorParameter)

InputParameter = _reflection.GeneratedProtocolMessageType('InputParameter', (_message.Message,), {
  'DESCRIPTOR' : _INPUTPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:InputParameter)
  })
_sym_db.RegisterMessage(InputParameter)

Conv1dParameter = _reflection.GeneratedProtocolMessageType('Conv1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _CONV1DPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:Conv1dParameter)
  })
_sym_db.RegisterMessage(Conv1dParameter)

DenseParameter = _reflection.GeneratedProtocolMessageType('DenseParameter', (_message.Message,), {
  'DESCRIPTOR' : _DENSEPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:DenseParameter)
  })
_sym_db.RegisterMessage(DenseParameter)

ActivationParameter = _reflection.GeneratedProtocolMessageType('ActivationParameter', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATIONPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:ActivationParameter)
  })
_sym_db.RegisterMessage(ActivationParameter)

MaxPool1dParameter = _reflection.GeneratedProtocolMessageType('MaxPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _MAXPOOL1DPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:MaxPool1dParameter)
  })
_sym_db.RegisterMessage(MaxPool1dParameter)

AvgPool1dParameter = _reflection.GeneratedProtocolMessageType('AvgPool1dParameter', (_message.Message,), {
  'DESCRIPTOR' : _AVGPOOL1DPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:AvgPool1dParameter)
  })
_sym_db.RegisterMessage(AvgPool1dParameter)

LaneFeatureConvParameter = _reflection.GeneratedProtocolMessageType('LaneFeatureConvParameter', (_message.Message,), {
  'DESCRIPTOR' : _LANEFEATURECONVPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:LaneFeatureConvParameter)
  })
_sym_db.RegisterMessage(LaneFeatureConvParameter)

ObsFeatureFCParameter = _reflection.GeneratedProtocolMessageType('ObsFeatureFCParameter', (_message.Message,), {
  'DESCRIPTOR' : _OBSFEATUREFCPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:ObsFeatureFCParameter)
  })
_sym_db.RegisterMessage(ObsFeatureFCParameter)

ClassifyParameter = _reflection.GeneratedProtocolMessageType('ClassifyParameter', (_message.Message,), {
  'DESCRIPTOR' : _CLASSIFYPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:ClassifyParameter)
  })
_sym_db.RegisterMessage(ClassifyParameter)

RegressParameter = _reflection.GeneratedProtocolMessageType('RegressParameter', (_message.Message,), {
  'DESCRIPTOR' : _REGRESSPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:RegressParameter)
  })
_sym_db.RegisterMessage(RegressParameter)

CruiseModelParameter = _reflection.GeneratedProtocolMessageType('CruiseModelParameter', (_message.Message,), {
  'DESCRIPTOR' : _CRUISEMODELPARAMETER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.cruise_model_pb2'
  # @@protoc_insertion_point(class_scope:CruiseModelParameter)
  })
_sym_db.RegisterMessage(CruiseModelParameter)


_TENSORPARAMETER.fields_by_name['data']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_ultrasonic.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_ultrasonic.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/perception/proto/perception_ultrasonic.proto\x12\x11\x61pollo.perception\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"|\n\x16ImpendingCollisionEdge\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x18\n\x0c\x63one_id_list\x18\x02 \x03(\x05\x42\x02\x18\x01\x12%\n\x05point\x18\x03 \x03(\x0b\x32\x16.apollo.common.Point3D\x12\x15\n\rtracking_time\x18\x04 \x01(\x01\"\x8d\x01\n\x17ImpendingCollisionEdges\x12K\n\x18impending_collision_edge\x18\x01 \x03(\x0b\x32).apollo.perception.ImpendingCollisionEdge\x12%\n\x06header\x18\x02 \x01(\x0b\x32\x15.apollo.common.Header'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_IMPENDINGCOLLISIONEDGE = _descriptor.Descriptor(
  name='ImpendingCollisionEdge',
  full_name='apollo.perception.ImpendingCollisionEdge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.perception.ImpendingCollisionEdge.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cone_id_list', full_name='apollo.perception.ImpendingCollisionEdge.cone_id_list', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.perception.ImpendingCollisionEdge.point', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracking_time', full_name='apollo.perception.ImpendingCollisionEdge.tracking_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=271,
)


_IMPENDINGCOLLISIONEDGES = _descriptor.Descriptor(
  name='ImpendingCollisionEdges',
  full_name='apollo.perception.ImpendingCollisionEdges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='impending_collision_edge', full_name='apollo.perception.ImpendingCollisionEdges.impending_collision_edge', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.ImpendingCollisionEdges.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=415,
)

_IMPENDINGCOLLISIONEDGE.fields_by_name['point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_IMPENDINGCOLLISIONEDGES.fields_by_name['impending_collision_edge'].message_type = _IMPENDINGCOLLISIONEDGE
_IMPENDINGCOLLISIONEDGES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['ImpendingCollisionEdge'] = _IMPENDINGCOLLISIONEDGE
DESCRIPTOR.message_types_by_name['ImpendingCollisionEdges'] = _IMPENDINGCOLLISIONEDGES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImpendingCollisionEdge = _reflection.GeneratedProtocolMessageType('ImpendingCollisionEdge', (_message.Message,), {
  'DESCRIPTOR' : _IMPENDINGCOLLISIONEDGE,
  '__module__' : 'modules.perception.proto.perception_ultrasonic_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.ImpendingCollisionEdge)
  })
_sym_db.RegisterMessage(ImpendingCollisionEdge)

ImpendingCollisionEdges = _reflection.GeneratedProtocolMessageType('ImpendingCollisionEdges', (_message.Message,), {
  'DESCRIPTOR' : _IMPENDINGCOLLISIONEDGES,
  '__module__' : 'modules.perception.proto.perception_ultrasonic_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.ImpendingCollisionEdges)
  })
_sym_db.RegisterMessage(ImpendingCollisionEdges)


_IMPENDINGCOLLISIONEDGE.fields_by_name['cone_id_list']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/geometry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/geometry.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/common/proto/geometry.proto\x12\rapollo.common\"8\n\x08PointENU\x12\x0e\n\x01x\x18\x01 \x01(\x01:\x03nan\x12\x0e\n\x01y\x18\x02 \x01(\x01:\x03nan\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\"A\n\x08PointLLH\x12\x10\n\x03lon\x18\x01 \x01(\x01:\x03nan\x12\x10\n\x03lat\x18\x02 \x01(\x01:\x03nan\x12\x11\n\x06height\x18\x03 \x01(\x01:\x01\x30\")\n\x07Point2D\x12\x0e\n\x01x\x18\x01 \x01(\x01:\x03nan\x12\x0e\n\x01y\x18\x02 \x01(\x01:\x03nan\"9\n\x07Point3D\x12\x0e\n\x01x\x18\x01 \x01(\x01:\x03nan\x12\x0e\n\x01y\x18\x02 \x01(\x01:\x03nan\x12\x0e\n\x01z\x18\x03 \x01(\x01:\x03nan\"P\n\nQuaternion\x12\x0f\n\x02qx\x18\x01 \x01(\x01:\x03nan\x12\x0f\n\x02qy\x18\x02 \x01(\x01:\x03nan\x12\x0f\n\x02qz\x18\x03 \x01(\x01:\x03nan\x12\x0f\n\x02qw\x18\x04 \x01(\x01:\x03nan\"0\n\x07Polygon\x12%\n\x05point\x18\x01 \x03(\x0b\x32\x16.apollo.common.Point3D'
)




_POINTENU = _descriptor.Descriptor(
  name='PointENU',
  full_name='apollo.common.PointENU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.common.PointENU.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.common.PointENU.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.common.PointENU.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=110,
)


_POINTLLH = _descriptor.Descriptor(
  name='PointLLH',
  full_name='apollo.common.PointLLH',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lon', full_name='apollo.common.PointLLH.lon', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='apollo.common.PointLLH.lat', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.common.PointLLH.height', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=177,
)


_POINT2D = _descriptor.Descriptor(
  name='Point2D',
  full_name='apollo.common.Point2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.common.Point2D.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.common.Point2D.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=220,
)


_POINT3D = _descriptor.Descriptor(
  name='Point3D',
  full_name='apollo.common.Point3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.common.Point3D.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.common.Point3D.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.common.Point3D.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=279,
)


_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='apollo.common.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='qx', full_name='apollo.common.Quaternion.qx', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qy', full_name='apollo.common.Quaternion.qy', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qz', full_name='apollo.common.Quaternion.qz', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qw', full_name='apollo.common.Quaternion.qw', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=361,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='apollo.common.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.common.Polygon.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=411,
)

_POLYGON.fields_by_name['point'].message_type = _POINT3D
DESCRIPTOR.message_types_by_name['PointENU'] = _POINTENU
DESCRIPTOR.message_types_by_name['PointLLH'] = _POINTLLH
DESCRIPTOR.message_types_by_name['Point2D'] = _POINT2D
DESCRIPTOR.message_types_by_name['Point3D'] = _POINT3D
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointENU = _reflection.GeneratedProtocolMessageType('PointENU', (_message.Message,), {
  'DESCRIPTOR' : _POINTENU,
  '__module__' : 'modules.common.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.PointENU)
  })
_sym_db.RegisterMessage(PointENU)

PointLLH = _reflection.GeneratedProtocolMessageType('PointLLH', (_message.Message,), {
  'DESCRIPTOR' : _POINTLLH,
  '__module__' : 'modules.common.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.PointLLH)
  })
_sym_db.RegisterMessage(PointLLH)

Point2D = _reflection.GeneratedProtocolMessageType('Point2D', (_message.Message,), {
  'DESCRIPTOR' : _POINT2D,
  '__module__' : 'modules.common.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Point2D)
  })
_sym_db.RegisterMessage(Point2D)

Point3D = _reflection.GeneratedProtocolMessageType('Point3D', (_message.Message,), {
  'DESCRIPTOR' : _POINT3D,
  '__module__' : 'modules.common.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Point3D)
  })
_sym_db.RegisterMessage(Point3D)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'modules.common.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'modules.common.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Polygon)
  })
_sym_db.RegisterMessage(Polygon)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/run_mode_conf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/run_mode_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63yber/proto/run_mode_conf.proto\x12\x12\x61pollo.cyber.proto\"\x89\x01\n\x0bRunModeConf\x12;\n\x08run_mode\x18\x01 \x01(\x0e\x32\x1b.apollo.cyber.proto.RunMode:\x0cMODE_REALITY\x12=\n\nclock_mode\x18\x02 \x01(\x0e\x32\x1d.apollo.cyber.proto.ClockMode:\nMODE_CYBER*0\n\x07RunMode\x12\x10\n\x0cMODE_REALITY\x10\x00\x12\x13\n\x0fMODE_SIMULATION\x10\x01**\n\tClockMode\x12\x0e\n\nMODE_CYBER\x10\x00\x12\r\n\tMODE_MOCK\x10\x01'
)

_RUNMODE = _descriptor.EnumDescriptor(
  name='RunMode',
  full_name='apollo.cyber.proto.RunMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_REALITY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_SIMULATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=195,
  serialized_end=243,
)
_sym_db.RegisterEnumDescriptor(_RUNMODE)

RunMode = enum_type_wrapper.EnumTypeWrapper(_RUNMODE)
_CLOCKMODE = _descriptor.EnumDescriptor(
  name='ClockMode',
  full_name='apollo.cyber.proto.ClockMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_CYBER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODE_MOCK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=245,
  serialized_end=287,
)
_sym_db.RegisterEnumDescriptor(_CLOCKMODE)

ClockMode = enum_type_wrapper.EnumTypeWrapper(_CLOCKMODE)
MODE_REALITY = 0
MODE_SIMULATION = 1
MODE_CYBER = 0
MODE_MOCK = 1



_RUNMODECONF = _descriptor.Descriptor(
  name='RunModeConf',
  full_name='apollo.cyber.proto.RunModeConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_mode', full_name='apollo.cyber.proto.RunModeConf.run_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_mode', full_name='apollo.cyber.proto.RunModeConf.clock_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=193,
)

_RUNMODECONF.fields_by_name['run_mode'].enum_type = _RUNMODE
_RUNMODECONF.fields_by_name['clock_mode'].enum_type = _CLOCKMODE
DESCRIPTOR.message_types_by_name['RunModeConf'] = _RUNMODECONF
DESCRIPTOR.enum_types_by_name['RunMode'] = _RUNMODE
DESCRIPTOR.enum_types_by_name['ClockMode'] = _CLOCKMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunModeConf = _reflection.GeneratedProtocolMessageType('RunModeConf', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODECONF,
  '__module__' : 'cyber.proto.run_mode_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.RunModeConf)
  })
_sym_db.RegisterMessage(RunModeConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/roi_boundary_filter_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/roi_boundary_filter_config.proto',
  package='apollo.perception.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9modules/perception/proto/roi_boundary_filter_config.proto\x12\x17\x61pollo.perception.lidar\"\xa6\x01\n\x17ROIBoundaryFilterConfig\x12)\n\x1e\x64istance_to_boundary_threshold\x18\x01 \x01(\x01:\x01\x31\x12!\n\x14\x63onfidence_threshold\x18\x02 \x01(\x02:\x03\x30.5\x12 \n\x13\x63ross_roi_threshold\x18\x03 \x01(\x02:\x03\x30.6\x12\x1b\n\x10inside_threshold\x18\x04 \x01(\x01:\x01\x31'
)




_ROIBOUNDARYFILTERCONFIG = _descriptor.Descriptor(
  name='ROIBoundaryFilterConfig',
  full_name='apollo.perception.lidar.ROIBoundaryFilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance_to_boundary_threshold', full_name='apollo.perception.lidar.ROIBoundaryFilterConfig.distance_to_boundary_threshold', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence_threshold', full_name='apollo.perception.lidar.ROIBoundaryFilterConfig.confidence_threshold', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_roi_threshold', full_name='apollo.perception.lidar.ROIBoundaryFilterConfig.cross_roi_threshold', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.6),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inside_threshold', full_name='apollo.perception.lidar.ROIBoundaryFilterConfig.inside_threshold', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=253,
)

DESCRIPTOR.message_types_by_name['ROIBoundaryFilterConfig'] = _ROIBOUNDARYFILTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ROIBoundaryFilterConfig = _reflection.GeneratedProtocolMessageType('ROIBoundaryFilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _ROIBOUNDARYFILTERCONFIG,
  '__module__' : 'modules.perception.proto.roi_boundary_filter_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.lidar.ROIBoundaryFilterConfig)
  })
_sym_db.RegisterMessage(ROIBoundaryFilterConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/latency_recorder/proto/latency_record.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/latency_recorder/proto/latency_record.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:modules/common/latency_recorder/proto/latency_record.proto\x12\rapollo.common\x1a!modules/common/proto/header.proto\"I\n\rLatencyRecord\x12\x12\n\nbegin_time\x18\x01 \x01(\x04\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\x04\x12\x12\n\nmessage_id\x18\x03 \x01(\x04\"\x85\x01\n\x10LatencyRecordMap\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x13\n\x0bmodule_name\x18\x02 \x01(\t\x12\x35\n\x0flatency_records\x18\x03 \x03(\x0b\x32\x1c.apollo.common.LatencyRecord\"z\n\x0bLatencyStat\x12)\n\x0cmin_duration\x18\x01 \x01(\x04:\x13\x39\x32\x32\x33\x33\x37\x32\x30\x33\x36\x38\x35\x34\x37\x37\x35\x38\x30\x38\x12\x14\n\x0cmax_duration\x18\x02 \x01(\x04\x12\x15\n\raver_duration\x18\x03 \x01(\x04\x12\x13\n\x0bsample_size\x18\x04 \x01(\r\"\xb5\x01\n\x0cLatencyTrack\x12\x46\n\rlatency_track\x18\x01 \x03(\x0b\x32/.apollo.common.LatencyTrack.LatencyTrackMessage\x1a]\n\x13LatencyTrackMessage\x12\x14\n\x0clatency_name\x18\x01 \x01(\t\x12\x30\n\x0clatency_stat\x18\x02 \x01(\x0b\x32\x1a.apollo.common.LatencyStat\"\x9f\x01\n\rLatencyReport\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x31\n\x0c\x65\x32\x65s_latency\x18\x02 \x01(\x0b\x32\x1b.apollo.common.LatencyTrack\x12\x34\n\x0fmodules_latency\x18\x03 \x01(\x0b\x32\x1b.apollo.common.LatencyTrack'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_LATENCYRECORD = _descriptor.Descriptor(
  name='LatencyRecord',
  full_name='apollo.common.LatencyRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin_time', full_name='apollo.common.LatencyRecord.begin_time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='apollo.common.LatencyRecord.end_time', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='apollo.common.LatencyRecord.message_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=185,
)


_LATENCYRECORDMAP = _descriptor.Descriptor(
  name='LatencyRecordMap',
  full_name='apollo.common.LatencyRecordMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.common.LatencyRecordMap.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='apollo.common.LatencyRecordMap.module_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_records', full_name='apollo.common.LatencyRecordMap.latency_records', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=321,
)


_LATENCYSTAT = _descriptor.Descriptor(
  name='LatencyStat',
  full_name='apollo.common.LatencyStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_duration', full_name='apollo.common.LatencyStat.min_duration', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=9223372036854775808,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_duration', full_name='apollo.common.LatencyStat.max_duration', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aver_duration', full_name='apollo.common.LatencyStat.aver_duration', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_size', full_name='apollo.common.LatencyStat.sample_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=445,
)


_LATENCYTRACK_LATENCYTRACKMESSAGE = _descriptor.Descriptor(
  name='LatencyTrackMessage',
  full_name='apollo.common.LatencyTrack.LatencyTrackMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latency_name', full_name='apollo.common.LatencyTrack.LatencyTrackMessage.latency_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_stat', full_name='apollo.common.LatencyTrack.LatencyTrackMessage.latency_stat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=629,
)

_LATENCYTRACK = _descriptor.Descriptor(
  name='LatencyTrack',
  full_name='apollo.common.LatencyTrack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latency_track', full_name='apollo.common.LatencyTrack.latency_track', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LATENCYTRACK_LATENCYTRACKMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=629,
)


_LATENCYREPORT = _descriptor.Descriptor(
  name='LatencyReport',
  full_name='apollo.common.LatencyReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.common.LatencyReport.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='e2es_latency', full_name='apollo.common.LatencyReport.e2es_latency', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules_latency', full_name='apollo.common.LatencyReport.modules_latency', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=791,
)

_LATENCYRECORDMAP.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_LATENCYRECORDMAP.fields_by_name['latency_records'].message_type = _LATENCYRECORD
_LATENCYTRACK_LATENCYTRACKMESSAGE.fields_by_name['latency_stat'].message_type = _LATENCYSTAT
_LATENCYTRACK_LATENCYTRACKMESSAGE.containing_type = _LATENCYTRACK
_LATENCYTRACK.fields_by_name['latency_track'].message_type = _LATENCYTRACK_LATENCYTRACKMESSAGE
_LATENCYREPORT.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_LATENCYREPORT.fields_by_name['e2es_latency'].message_type = _LATENCYTRACK
_LATENCYREPORT.fields_by_name['modules_latency'].message_type = _LATENCYTRACK
DESCRIPTOR.message_types_by_name['LatencyRecord'] = _LATENCYRECORD
DESCRIPTOR.message_types_by_name['LatencyRecordMap'] = _LATENCYRECORDMAP
DESCRIPTOR.message_types_by_name['LatencyStat'] = _LATENCYSTAT
DESCRIPTOR.message_types_by_name['LatencyTrack'] = _LATENCYTRACK
DESCRIPTOR.message_types_by_name['LatencyReport'] = _LATENCYREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LatencyRecord = _reflection.GeneratedProtocolMessageType('LatencyRecord', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYRECORD,
  '__module__' : 'modules.common.latency_recorder.proto.latency_record_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.LatencyRecord)
  })
_sym_db.RegisterMessage(LatencyRecord)

LatencyRecordMap = _reflection.GeneratedProtocolMessageType('LatencyRecordMap', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYRECORDMAP,
  '__module__' : 'modules.common.latency_recorder.proto.latency_record_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.LatencyRecordMap)
  })
_sym_db.RegisterMessage(LatencyRecordMap)

LatencyStat = _reflection.GeneratedProtocolMessageType('LatencyStat', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYSTAT,
  '__module__' : 'modules.common.latency_recorder.proto.latency_record_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.LatencyStat)
  })
_sym_db.RegisterMessage(LatencyStat)

LatencyTrack = _reflection.GeneratedProtocolMessageType('LatencyTrack', (_message.Message,), {

  'LatencyTrackMessage' : _reflection.GeneratedProtocolMessageType('LatencyTrackMessage', (_message.Message,), {
    'DESCRIPTOR' : _LATENCYTRACK_LATENCYTRACKMESSAGE,
    '__module__' : 'modules.common.latency_recorder.proto.latency_record_pb2'
    # @@protoc_insertion_point(class_scope:apollo.common.LatencyTrack.LatencyTrackMessage)
    })
  ,
  'DESCRIPTOR' : _LATENCYTRACK,
  '__module__' : 'modules.common.latency_recorder.proto.latency_record_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.LatencyTrack)
  })
_sym_db.RegisterMessage(LatencyTrack)
_sym_db.RegisterMessage(LatencyTrack.LatencyTrackMessage)

LatencyReport = _reflection.GeneratedProtocolMessageType('LatencyReport', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYREPORT,
  '__module__' : 'modules.common.latency_recorder.proto.latency_record_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.LatencyReport)
  })
_sym_db.RegisterMessage(LatencyReport)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

# Copyright 2022 daohu527 <daohu527@gmail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from record_msg.builder import ImageBuilder, PointCloudBuilder


def test_image_builder():
  img_path = 'test.jpg'
  image_builder = ImageBuilder()
  pb_image = image_builder.build(img_path, encoding='rgb8')
  print(pb_image)


def test_point_cloud_builder():
  point_cloud_path = 'test.pcd'
  point_cloud_builder = PointCloudBuilder()
  pb_point_cloud = point_cloud_builder.build(point_cloud_path)
  print(pb_point_cloud)


if __name__ == '__main__':
  # test_image_builder()
  test_point_cloud_builder()
